TypeVar

Struct TypeVar 

pub struct TypeVar {
    pub id: usize,
    pub name: String,
}
Type variable identifier.

Type variables represent unknown types during type inference. Examples: ’a, ’b, ’t1, ’t2

Fields

id: usize

Unique identifier for this type variable

name: String

Human-readable name (e.g., “a”, “b”, “t1”)

Implementations

Source

impl TypeVar

pub fn new(id: usize, name: impl Into<String>) -> Self

Create a new type variable with the given id and name.

pub fn fresh(id: usize) -> Self

Create a fresh type variable with a generated name.